<?php
namespace Thombo\Sishandball2\Controller;

/***************************************************************
 *  Copyright notice
 *
 *  (c) 2016 Thomas Bodenbender <info@thombo.com>, 
 *  thombo Softwareentwicklung und IT-Beratungs GmbH
 *
 *  All rights reserved
 *
 *  This script is part of the TYPO3 project. The TYPO3 project is
 *  free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  The GNU General Public License can be found at
 *  http://www.gnu.org/copyleft/gpl.html.
 *
 *  This script is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  This copyright notice MUST APPEAR in all copies of the script!
 ***************************************************************/

/**
 *
 *
 * @license http://www.gnu.org/licenses/gpl.html GNU General Public License, version 3 or later
 *
 */
class MatchController extends \TYPO3\CMS\Extbase\Mvc\Controller\ActionController {

	/**
	 * matchRepository
	 *
	 * @var \Thombo\Sishandball2\Domain\Repository\MatchRepository
	 * @inject
	 */
	protected $matchRepository;

	/**
	 * LeagueRepository
	 *
	 * @var \Thombo\Sishandball2\Domain\Repository\LeagueRepository
	 * @inject
	 */
	protected $leagueRepository;

	/**
	 * TeamRepository
	 *
	 * @var \Thombo\Sishandball2\Domain\Repository\TeamRepository
	 * @inject
	 */
	protected $teamRepository;

	/**
	 * ClubRepository
	 *
	 * @var \Thombo\Sishandball2\Domain\Repository\ClubRepository
	 * @inject
	 */
	protected $clubRepository;

	/**
	 * SpecialTeamShortRepository
	 *
	 * @var \Thombo\Sishandball2\Domain\Repository\SpecialTeamShortRepository
	 * @inject
	 */
	protected $specialTeamShortRepository;

	/**
	 * action matches4Team
	 *
	 * @return void
	 */
	public function matches4TeamAction() {
		$matches = $this->handle('teammatches');

		if($this->settings['teammatches']['displaySelection'] == 1) {
			$this->view->assign('matchhlfcount', count($matches) / 2);

			if($this->settings['teammatches']['actualcheckbox']) {
				foreach($matches as $match) {
					if($match->getMatchdate()->format('U') > time()) {
						$this->view->assign('nextmatch', $match);
						break;
					}
				}
			}

			reset($matches);
		}

		$this->view->assign('settings', $this->settings['teammatches']);
		$this->view->assign('matches', $matches);
	}

	/**
	 * action matches4League
	 *
	 * @return void
	 */
	public function matches4LeagueAction() {
		$matches = $this->handle('leaguematches');

		$objMatchPlan = new \Thombo\Sishandball2\Domain\Model\Matchplan();
		$objMatchPlan->setSettings($this->settings['leaguematches']);
		$objMatchPlan->parseQueryResult($matches);

		if($this->settings['leaguematches']['displaySelection'] == 1) {
			if(!empty($this->settings['leaguematches']['linktoactualmatchday'])) {
				$iActLinkValue = 0;
				foreach($objMatchPlan->aMatchDays as $iKey => $iMatchDayCode) {
					if($iMatchDayCode >= date('yW')) {
						$iActLinkValue = ceil($iKey / $this->settings['leaguematches']['matchdaysperpage']) - 1;;
						break;
					}
				}

				reset($objMatchPlan->aMatchDays);

				if($this->request->hasArgument('page') && $iActLinkValue != $this->request->getArgument('page')) {
					$this->view->assign('actpage', $iActLinkValue);
				}
			}

			$iMatchDayCount = count($objMatchPlan->getMatchdays());

			$iItemsPerPage = intval($this->settings['leaguematches']['matchdaysperpage']);

			$iPage = 0;
			if($this->request->hasArgument('page')) {
				$iPage = $this->request->getArgument('page');
			}

			$aPagination = array();

			if(!empty($iItemsPerPage) && $iMatchDayCount > $iItemsPerPage) {
				$iQueryOffset = $iItemsPerPage * $iPage;
				$objMatchPlan->setOffset($iQueryOffset, $iItemsPerPage);

				$iPages = ceil($iMatchDayCount / $iItemsPerPage);

				if ($iPages <= 10) {
					$iMinPagination = 0;
					$iMaxPagination = $iPages;
				}

				if ($iPages > 10) {
					$iMaxPagination = $iPage + 5;
					if ($iMaxPagination > $iPages) {
						$iMaxPagination = $iPages;
					}

					$iMinPagination = $iMaxPagination - 10;
					if($iMinPagination < 0) {
						$iMinPagination = 0;
						$iMaxPagination = 10;
					}
				}

				for ($i = $iMinPagination; $i <= $iMaxPagination; $i++) {
					$aPagination['pages'][$i]['text'] = $i;
				}

				if($iPage > 1) {
					$aPagination['prev'] = $iPage - 1;
				}
				if($iPage < $iPages) {
					$aPagination['next'] = $iPage + 1;
				}

				if($iMinPagination > 1){
					$aPagination['first'] = 1;
				}
				if($iMaxPagination < $iPages){
					$aPagination['last'] = $iPages;
				}

				$aPagination['current'] = $page;
			}

			$this->view->assign('pagination', $aPagination);
		}

		if($this->settings['leaguematches']['displaySelection'] == 2) {
			if($this->settings['leaguematches']['jumptonextrealmatch']) {
				$iFromTime = time();
				$iTestTimestamp = time();

				$iTestdayNo = date('w',$iTestTimestamp);
				if($iTestdayNo == 0) {
					$iTestdayNo = 7;
				}

				if($iTestdayNo >= $this->settings['leaguematches']['nextdayactual']) {
					$iFromTime = $this->getMonday($iTestTimestamp);
				} else {
					$iFromTime = $this->getMonday($iTestTimestamp - (60*60*24*7));
				}

				if(!empty($this->settings['leaguematches']['relativeweekend'])) {
					$iFromTime = strtotime('+'.$this->aConf['relativeweekend'].' week', $iFromTime);
				}

				$iUntilTime = strtotime('+1 week', $iFromTime) - 1;

				if(count($objMatchPlan->getMatchdays()) != 0 && count($objMatchPlan->getMatchdays()->current()->getMatches())) {
					$iFirstmatchdate = $objMatchPlan->getMatchdays()->current()->getMatches()->current()->getMatchdate()->format('U');
					if($iFirstmatchdate > $iFromTime && $iFirstmatchdate < $iUntilTime) {
						$this->view->assign('jumpedweek', FALSE);
					} else {
						$this->view->assign('jumpedweek', TRUE);
					}
				}
			}
		}

		$this->view->assign('settings', $this->settings['leaguematches']);
		$this->view->assign('matchplan', $objMatchPlan);

	}

	/**
	 * action matches4club
	 *
	 * @return void
	 */
	public function matches4ClubAction() {
		$this->settings['clubmatches']['teams'] = $this->teamRepository->findByClub($this->settings['clubmatches']['clubSelection'], $this->settings['pages']);
		$this->settings['clubmatches']['specialTeamShorts'] = $this->specialTeamShortRepository->findAllInPage($this->settings['pages']);

		$matches = $this->handle('clubmatches');

		$objMatchPlan = new \Thombo\Sishandball2\Domain\Model\Matchplan();
		$objMatchPlan->setSettings($this->settings['clubmatches']);
		$objMatchPlan->parseQueryResult($matches);

		if($this->settings['clubmatches']['displayselection'] == 1) {
			if(!empty($this->settings['clubmatches']['linktoactualmatchday'])) {
				$iActLinkValue = 0;
				foreach($objMatchPlan->aMatchDays as $iKey => $iMatchDayCode) {
					if($iMatchDayCode >= date('yW')) {
						$iActLinkValue = ceil($iKey / $this->settings['clubmatches']['matchdaysperpage']) - 1;
						break;
					}
				}

				reset($objMatchPlan->aMatchDays);

				if($this->request->hasArgument('page') && $iActLinkValue != $this->request->getArgument('page')) {
					$this->view->assign('actpage', $iActLinkValue);
				}
			}

			$iMatchDayCount = count($objMatchPlan->getMatchdays());

			$iItemsPerPage = intval($this->settings['clubmatches']['matchdaysperpage']);

			$iPage = 0;
			if($this->request->hasArgument('page')) {
				$iPage = $this->request->getArgument('page');
			}

			$aPagination = array();

			if(!empty($iItemsPerPage) && $iMatchDayCount > $iItemsPerPage) {
				$iQueryOffset = $iItemsPerPage * $iPage;
				$objMatchPlan->setOffset($iQueryOffset, $iItemsPerPage);

				$iPages = ceil($iMatchDayCount / $iItemsPerPage);

				if ($iPages <= 10) {
					$iMinPagination = 0;
					$iMaxPagination = $iPages;
				}

				if ($iPages > 10) {
					$iMaxPagination = $iPage + 5;
					if ($iMaxPagination > $iPages) {
						$iMaxPagination = $iPages;
					}

					$iMinPagination = $iMaxPagination - 10;
					if($iMinPagination < 0) {
						$iMinPagination = 0;
						$iMaxPagination = 10;
					}
				}

				for ($i = $iMinPagination; $i <= $iMaxPagination; $i++) {
					$aPagination['pages'][$i]['text'] = $i;
				}

				if($iPage > 1) {
					$aPagination['prev'] = $iPage - 1;
				}
				if($iPage < $iPages) {
					$aPagination['next'] = $iPage + 1;
				}

				if($iMinPagination > 1){
					$aPagination['first'] = 1;
				}
				if($iMaxPagination < $iPages){
					$aPagination['last'] = $iPages;
				}

				$aPagination['current'] = $page;
			}

			$this->view->assign('pagination', $aPagination);
		}

		if($this->settings['clubmatches']['displayselection'] == 2) {
			if($this->settings['clubmatches']['jumptonextrealmatch']) {
				$iFromTime = time();
				$iTestTimestamp = time();

				$iTestdayNo = date('w',$iTestTimestamp);
				if($iTestdayNo == 0) {
					$iTestdayNo = 7;
				}

				if($iTestdayNo >= $this->settings['clubmatches']['nextdayactual']) {
					$iFromTime = $this->getMonday($iTestTimestamp);
				} else {
					$iFromTime = $this->getMonday($iTestTimestamp - (60*60*24*7));
				}

				if(!empty($this->settings['clubmatches']['relativeweekend'])) {
					$iFromTime = strtotime('+'.$this->settings['clubmatches']['relativeweekend'].' week', $iFromTime);
				}

				$iUntilTime = strtotime('+1 week', $iFromTime);

				if(count($objMatchPlan->getMatchdays()) != 0 && count($objMatchPlan->getMatchdays()->current()->getMatches())) {
					$iFirstmatchdate = $objMatchPlan->getMatchdays()->current()->getMatches()->current()->getMatchdate()->format('U');
					if($iFirstmatchdate > $iFromTime && $iFirstmatchdate < $iUntilTime) {
						$this->view->assign('jumpedweek', FALSE);
					} else {
						$this->view->assign('jumpedweek', TRUE);
					}
				}
			}
		}

		$this->view->assign('settings', $this->settings['clubmatches']);
		$this->view->assign('matchplan', $objMatchPlan);
	}

	/**
	 * action createTable
	 *
	 * @return void
	 */
	public function createTableAction() {
		if(!(bool)$this->settings['table']['displaywithoutsoring']) {
			$this->settings['table']['teams'] = $this->teamRepository->findWithdrawed($this->settings['table']['leagueSelection'], $this->settings['pages']);
		}

		$matches = $this->handle('table');

		$aTable = array();
		foreach($matches as $match) {
			$iHomeUid = $match->getHome()->getUid();
			$iGuestUid = $match->getGuest()->getUid();

			$aTable[$iHomeUid]['team'] = $match->getHome();
			$aTable[$iHomeUid]['marked'] = ($match->getHome() == $this->settings['table']['teamSelection']);
			if($this->settings['table']['homeawayrestriction'] == 0 || $this->settings['table']['homeawayrestriction'] == 1) {
				$aTable[$iHomeUid]['matchcount']++;
				if($match->getPtsH() != 0 || $match->getPtsG() != 0) {
					$aTable[$iHomeUid]['playedcount']++;
				}
			}

			if(empty($aTable[$iHomeUid]['playedcount']) && $aTable[$iHomeUid]['playedcount'] !== 0) {
				$aTable[$iHomeUid]['playedcount'] = 0;
			}

			$aTable[$iGuestUid]['team'] = $match->getGuest();
			$aTable[$iGuestUid]['marked'] = ($match->getGuest() == $this->settings['table']['teamSelection']);
			if($this->settings['table']['homeawayrestriction'] == 0 || $this->settings['table']['homeawayrestriction'] == 2) {
				$aTable[$iGuestUid]['matchcount']++;
				if($match->getPtsH() != 0 || $match->getPtsG() != 0) {
					$aTable[$iGuestUid]['playedcount']++;
				}
			}

			if(empty($aTable[$iGuestUid]['playedcount']) && $aTable[$iGuestUid]['playedcount'] !== 0) {
				$aTable[$iGuestUid]['playedcount'] = 0;
			}

			switch($this->settings['table']['homeawayrestriction']) {
				case 1:
					$aTable[$iHomeUid]['goals_h'] += $match->getRsltH();
					$aTable[$iHomeUid]['goals_g'] += $match->getRsltG();
					$aTable[$iHomeUid]['points_h'] += $match->getPtsH();
					$aTable[$iHomeUid]['points_g'] += $match->getPtsG();
					$aTable[$iHomeUid]['goaldiff'] += ($match->getRsltH() - $match->getRsltG());
					break;

				case 2:
					$aTable[$iGuestUid]['goals_h'] += $match->getRsltG();
					$aTable[$iGuestUid]['goals_g'] += $match->getRsltH();
					$aTable[$iGuestUid]['points_h'] += $match->getPtsG();
					$aTable[$iGuestUid]['points_g'] += $match->getPtsH();
					$aTable[$iGuestUid]['goaldiff'] += ($match->getRsltG() - $match->getRsltH());
					break;

				default:
					$aTable[$iHomeUid]['goals_h'] += $match->getRsltH();
					$aTable[$iHomeUid]['goals_g'] += $match->getRsltG();
					$aTable[$iHomeUid]['points_h'] += $match->getPtsH();
					$aTable[$iHomeUid]['points_g'] += $match->getPtsG();
					$aTable[$iHomeUid]['goaldiff'] += ($match->getRsltH() - $match->getRsltG());

					$aTable[$iGuestUid]['goals_h'] += $match->getRsltG();
					$aTable[$iGuestUid]['goals_g'] += $match->getRsltH();
					$aTable[$iGuestUid]['points_h'] += $match->getPtsG();
					$aTable[$iGuestUid]['points_g'] += $match->getPtsH();
					$aTable[$iGuestUid]['goaldiff'] += ($match->getRsltG() - $match->getRsltH());
					break;
			}
		}

		$aPointCountHome = array();
		$aGoalDiff = array();
		foreach ($aTable as $key => $row) {
			$aPointCountHome[$key]  = $row['points_h'];
			$aGoalDiff[$key] = $row['goaldiff'];
			$aPointCountGuest[$key] = $row['points_g'];
		}

		$aNewTablesort = array();
		if(empty($this->settings['table']['homeawayrestriction']) && $this->settings['table']['usedirectcomp']) {
			array_multisort($aPointCountHome, SORT_DESC, $aPointCountGuest, SORT_ASC, $aTable);

			$iPoints = $aTable[0]['points_h'];
			$aTmpTeams = array();
			foreach($aTable as $aTeam) {
				if($aTeam['points_h'] != $iPoints) {
					$this->sortByDirectComp($aTmpTeams,$aNewsTablesort,$matches);

					$iPoints = $aTeam['points_h'];
					$aTmpTeams[] = $aTeam;
				} else {
					$aTmpTeams[] = $aTeam;
				}
			}

			$this->sortByDirectComp($aTmpTeams,$aNewTablesort);
		} else {
			array_multisort($aPointCountHome, SORT_DESC, $aGoalDiff, SORT_DESC, $aTable);
			$aNewTablesort = $aLeagueTable;
		}

		$this->view->assign('settings', $this->settings['table']);
		$this->view->assign('table', $aTable);
	}

	/**
	 * action createCrossTable
	 *
	 * @return void
	 */
	public function createCrossTableAction() {
		$matches = $this->handle('crosstable');
		$teams = $this->teamRepository->findByLeague($this->settings['crosstable']['leagueSelection']->getUid(), $this->settings['pages']);

		foreach($teams as $team) {
			$aCrosstable[$team->getUid()] = array();
			$aCrosstable[$team->getUid()]['team'] = $team;

			$aCrosstable[$team->getUid()]['results'] = array();
		}

		foreach($aCrosstable as $iKey => $aData) {
			foreach($teams as $innerteam) {
				if($innerteam->getUid() == $aData['team']->getUid()) {
					$aCrosstable[$iKey]['results'][$innerteam->getUid()]['isResult'] = TRUE;
					$aCrosstable[$iKey]['results'][$innerteam->getUid()]['content'] = '--';

					if($this->settings['crosstable']['specialmarking']) {
						$sId = strtolower(preg_replace('/[\W|\s]/','',$aData['team']->getName())).strtolower(preg_replace('/[\W|\s]/','',$innerteam->getName()));
						$sIdPrefix = substr($sId,rand(0,strlen($sId)),1).substr($sId,rand(0,strlen($sId)),1);
						$aCrosstable[$iKey]['results'][$innerteam->getUid()]['marking'] = ' id="c'.$sIdPrefix.substr(md5($sId),3,6).'"';
					} else {
						$aCrosstable[$iKey]['results'][$innerteam->getUid()]['marking'] = '';
					}

				} else {
					$aCrosstable[$iKey]['results'][$innerteam->getUid()] = null;
				}

				$aCrosstable[$iKey]['results'][$innerteam->getUid()]['team'] = $innerteam;
			}
		}

		foreach($matches as $match) {
			if($match->getPtsH() != 0 || $match->getPtsG() != 0) {
				$aCrosstable[$match->getHome()->getUid()]['results'][$match->getGuest()->getUid()]['isResult'] = TRUE;
				$aCrosstable[$match->getHome()->getUid()]['results'][$match->getGuest()->getUid()]['content'] = $match->getRsltH().':'.$match->getRsltG();
			} else {
				$aCrosstable[$match->getHome()->getUid()]['results'][$match->getGuest()->getUid()]['isResult'] = FALSE;
				$aCrosstable[$match->getHome()->getUid()]['results'][$match->getGuest()->getUid()]['content'] = $match->getMatchdate();
			}

			if($this->settings['crosstable']['specialmarking']) {
				$sId = strtolower(preg_replace('/[\W|\s]/','',$match->getHome()->getName())).strtolower(preg_replace('/[\W|\s]/','',$match->getGuest()->getName()));
				$sIdPrefix = substr($sId,rand(0,strlen($sId)),1).substr($sId,rand(0,strlen($sId)),1);
				$aCrosstable[$match->getHome()->getUid()]['results'][$match->getGuest()->getUid()]['marking'] = ' id="'.$sIdPrefix.substr(md5($sId),3,6).'"';
			} else {
				$aCrosstable[$match->getHome()->getUid()]['results'][$match->getGuest()->getUid()]['marking'] = '';
			}
		}

		$this->view->assign('settings', $this->settings['crosstable']);
		$this->view->assign('crosstable', $aCrosstable);
		$this->view->assign('teams', $teams);
		$this->view->assign('referenceTeam', $this->settings['crosstable']['teamSelection']);
	}

	/**
	 * action matches4BE
	 *
	 * @return void
	 */
	public function matches4BEAction() {
		$params = array();
		$firstSelection = '';
		if($this->request->hasArgument('league') && $this->request->getArgument('league') != 0) {
			$params['league'] = $this->request->getArgument('league');
			$firstSelection = 'league';
			$this->view->assign('clubview', FALSE);
			$this->view->assign('selectedLeague', $this->request->getArgument('league'));

			$teams = $this->teamRepository->findByLeague($this->request->getArgument('league'), $_GET['id']);
			$this->view->assign('teams', $teams);

			$restrictedToTeam = 0;
			if($this->request->hasArgument('homeTeam') && $this->request->getArgument('homeTeam') != 0) {
				$restrictedToTeam = TRUE;
				$matches = $this->matchRepository->findByLeagueAndHomeTeam($this->request->getArgument('league'), $this->request->getArgument('homeTeam'), $_GET['id']);
				$params['homeTeam'] = $this->request->getArgument('homeTeam');
				$this->view->assign('selectedHome', $this->request->getArgument('homeTeam'));
			} else {
				$this->view->assign('selectedHome', NULL);
			}

			if($this->request->hasArgument('guestTeam') && $this->request->getArgument('guestTeam') != 0) {
				$restrictedToTeam = TRUE;
				$matches = $this->matchRepository->findByLeagueAndGuestTeam($this->request->getArgument('league'), $this->request->getArgument('guestTeam'), $_GET['id']);
				$params['guestTeam'] = $this->request->getArgument('guestTeam');
				$this->view->assign('selectedGuest', $this->request->getArgument('guestTeam'));
			} else {
				$this->view->assign('selectedGuest', NULL);
			}

			if(!$restrictedToTeam && $firstSelection == 'league') {
				$matches = $this->matchRepository->findByLeague($this->request->getArgument('league'), $_GET['id']);
			}
		} else {
			$this->view->assign('selectedLeague', NULL);
			$this->view->assign('teams', NULL);
		}

		$leagues = $this->leagueRepository->findAllInPage($_GET['id']);
		$this->view->assign('leagues', $leagues);

		if($this->request->hasArgument('club') && $this->request->getArgument('club') != 0) {
			$firstSelection = 'club';
			$this->view->assign('clubview', TRUE);
			$this->view->assign('selectedClub', $this->request->getArgument('club'));

			$teams = $this->teamRepository->findByClub($this->request->getArgument('club'), $_GET['id']);

			$params['club'] = $this->request->getArgument('club');
			$matches = $this->matchRepository->findByTeams($teams, $_GET['id']);
		} else {
			$this->view->assign('selectedClub', NULL);
		}

		$urlparameterString = '';
		$urlparameter = array('tx_sishandball2_web_sishandball2sishandball2' => $params);
		foreach($urlparameter['tx_sishandball2_web_sishandball2sishandball2'] as $key => $parameter) {
			$urlparameterString .= '&tx_sishandball2_web_sishandball2sishandball2['.$key.']='.$parameter;
		}

		$teamShorts = $this->specialTeamShortRepository->findAllInPage($_GET['id']);

		$this->view->assign('teamShorts', $teamShorts);

		if(!empty($_POST)) {
			$this->uriBuilder->reset();
			$this->uriBuilder->setArguments($urlparameter);

			$uri = $this->uriBuilder->buildBackendUri();

			\TYPO3\CMS\Core\Utility\HttpUtility::redirect($uri);
		}

		$clubs = $this->clubRepository->findAllInPage($_GET['id']);
		$this->view->assign('clubs', $clubs);

		$weeks = array();
		$dayMatches = array();
		$weekMatches = array();
		if(!empty($matches)) {
			$week = $matches[0]->getMatchdate()->format('W');
			$day = $matches[0]->getMatchdate()->format('dm');

			foreach($matches as $match) {
				if($match->getMatchdate()->format('dm') != $day) {
					$day = $match->getMatchdate()->format('dm');
					$weekMatches[] = $dayMatches;
					$dayMatches = array();
				}

				if($match->getMatchdate()->format('W') != $week) {
					$week = $match->getMatchdate()->format('W');
					$weeks[] = $weekMatches;
					$weekMatches = array();
				}

				$dayMatches[] = $match;
			}

			$weekMatches[] = $dayMatches;
			$weeks[] = $weekMatches;
		}

		$this->view->assign('weeks', $weeks);
	}

	private function handle($sSubpart) {
		array_walk_recursive($this->settings[$sSubpart], array($this, 'requestModels'));

		$this->matchRepository->setConfiguration($sSubpart, $this->settings);

		return $this->matchRepository->findRequested();
	}

	private function requestModels(&$sItem, $sKey) {
		if(strrev(substr(strrev($sKey),0,9)) == 'Selection') {
			$sModel = substr($sKey,0,strlen($sKey) - 9);
			switch($sModel) {
				case 'league':
					$sItem = $this->leagueRepository->findByUid($sItem);
					break;

				case 'team':
					$sItem = $this->teamRepository->findByUid($sItem);
					break;

				case 'club':
					$sItem = $this->clubRepository->findByUid($sItem);
					break;
			}
		}
	}

	private function getMonday($iTimeStamp) {
		$iMonday = '';

		if (strftime("%w",$iTimeStamp) != 0) {
			$iMonday = mktime(0,0,0,strftime("%m",$iTimeStamp),strftime("%d",$iTimeStamp)-strftime("%w",$iTimeStamp)+1,strftime("%Y",$iTimeStamp));
		} else {
			$iMonday = mktime(0,0,0,strftime("%m",$iTimeStamp),strftime("%d",$iTimeStamp)-6,strftime("%Y",$iTimeStamp));
		}

		return $iMonday;
	}

	private function sortByDirectComp(&$aTmpTeams, &$aNewTablesort, $matches) {
		if(count($aTmpTeams) < 2) {
			$aTmpTeams = array();
			return;
		}

		$lTeamUids = '';
		reset($aTmpTeams);
		foreach($aTmpTeams as $aTeam) {
			if(!empty($lTeamUids)) $lTeamUids .= ',';
			$lTeamUids .= $aTeam['team']->getUid();
		}

		reset($aTmpTeams);

		$aGoalDiff = array();
		$aPointCountHome = array();
		foreach($matches as $match) {
			if(\TYPO3\CMS\Core\Utility\GeneralUtility::inList($lTeamUids, $match->getHome()->getUid()) &&
			   \TYPO3\CMS\Core\Utility\GeneralUtility::inList($lTeamUids, $match->getGuest()->getUid())) {

				$iHomeUid = $match->getHome()->getUid();
				$iGuestUid = $match->getGuest()->getUid();

				$aTable[$iHomeUid]['goals_h'] += $match->getRsltH();
				$aTable[$iHomeUid]['goals_g'] += $match->getRsltG();
				$aTable[$iHomeUid]['points_h'] += $match->getPtsH();
				$aTable[$iHomeUid]['points_g'] += $match->getPtsG();
				$aTable[$iHomeUid]['goaldiff'] += ($match->getRsltH() - $match->getRsltG());

				$aTable[$iGuestUid]['goals_h'] += $match->getRsltG();
				$aTable[$iGuestUid]['goals_g'] += $match->getRsltH();
				$aTable[$iGuestUid]['points_h'] += $match->getPtsG();
				$aTable[$iGuestUid]['points_g'] += $match->getPtsH();
				$aTable[$iGuestUid]['goaldiff'] += ($match->getRsltG() - $match->getRsltH());

				$aPointCountHome[$iHomeUid] += $match->getPtsH();
				$aGoalDiff[$iHomeUid] += $match->getRsltH() - $match->getRsltG();

				$aPointCountHome[$iGuestUid] += $match->getPtsG();
				$aGoalDiff[$iGuestUid] += $match->getRsltG() - $match->getRsltH();
			}

		}

		/*
		foreach($aTmpTeams as $iKey => $aTeam) {
			$aDirectHomeMatches = $GLOBALS['TYPO3_DB']->exec_SELECTgetRows('SUM(`rslt_h`) as direct_rslt_h,
			                                                                SUM(`rslt_g`) as direct_rslt_g,
																	        SUM(`pts_h`) as direct_pts_h,
																	        SUM(`pts_g`) as direct_pts_g',
			'tx_sishandball_matches',
			'home = '.intval($aTeam['uid']).' AND guest IN ('.$lTeamUids.')');

			$aDirectGuestMatches = $GLOBALS['TYPO3_DB']->exec_SELECTgetRows('SUM(`rslt_h`) as direct_rslt_g,
			                                                                 SUM(`rslt_g`) as direct_rslt_h,
																	         SUM(`pts_h`) as direct_pts_g,
																	         SUM(`pts_g`) as direct_pts_h',
			'tx_sishandball_matches',
			'guest = '.intval($aTeam['uid']).' AND home IN ('.$lTeamUids.')');

			$aSumDirectMatches = array();
			$aSumDirectMatches['direct_rslt_h'] = $aDirectHomeMatches[0]['direct_rslt_h'] + $aDirectGuestMatches[0]['direct_rslt_h'];
			$aSumDirectMatches['direct_rslt_g'] = $aDirectHomeMatches[0]['direct_rslt_g'] + $aDirectGuestMatches[0]['direct_rslt_g'];
			$aSumDirectMatches['direct_pts_h'] = $aDirectHomeMatches[0]['direct_pts_h'] + $aDirectGuestMatches[0]['direct_pts_h'];
			$aSumDirectMatches['direct_pts_g'] = $aDirectHomeMatches[0]['direct_pts_g'] + $aDirectGuestMatches[0]['direct_pts_g'];

			$aTmpTeams[$iKey] = array_merge($aTmpTeams[$iKey],$aSumDirectMatches);

			$aPointCountHome[$iKey] = $aTmpTeams[$iKey]['direct_pts_h'];
			$aGoalDiff[$iKey] = $aTmpTeams[$iKey]['direct_rslt_h'] - $aTmpTeams['direct_rslt_g'];
		}
		*/

		array_multisort($aPointCountHome, SORT_DESC, $aGoalDiff, SORT_DESC, $aTmpTeams);

		reset($aTmpTeams);
		foreach($aTmpTeams as $aTeam) {
			$aNewTablesort[] = $aTeam;
		}

		$aTmpTeams = array();
	}

}
?>