<?php
namespace Thombo\Sishandball2\Domain\Model;

/***************************************************************
 *  Copyright notice
 *
 *  (c) 2013 Thomas Bodenbender <info@thombo.com>, thombo Softwareentwicklung und IT-Beratungs GmbH
 *
 *  All rights reserved
 *
 *  This script is part of the TYPO3 project. The TYPO3 project is
 *  free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  The GNU General Public License can be found at
 *  http://www.gnu.org/copyleft/gpl.html.
 *
 *  This script is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  This copyright notice MUST APPEAR in all copies of the script!
 ***************************************************************/

/**
 *
 *
 * @license http://www.gnu.org/licenses/gpl.html GNU General Public License, version 3 or later
 *
 */
class Matchplan extends \TYPO3\CMS\Extbase\DomainObject\AbstractEntity {

	/**
	 * matchdays
	 *
	 * @var \TYPO3\CMS\Extbase\Persistence\ObjectStorage<\Thombo\Sishandball2\Domain\Model\Matchday>
	 */
	protected $matchdays;

	/**
	 * settings
	 *
	 * @var array
	 */
	protected $settings;

	/**
	* aMatchDays
	*
	* @var array
	*/
	public $aMatchDays = array();

	/**
	 * __construct
	 *
	 * @return Matchplan
	 */
	public function __construct() {
		//Do not remove the next line: It would break the functionality
		$this->initStorageObjects();
	}

	/**
	 * Initializes all ObjectStorage properties.
	 *
	 * @return void
	 */
	protected function initStorageObjects() {
		/**
		 * Do not modify this method!
		 * It will be rewritten on each save in the extension builder
		 * You may modify the constructor of this class instead
		 */
		$this->matchdays = new \TYPO3\CMS\Extbase\Persistence\ObjectStorage();
	}

	/**
	 * Adds a Matchday
	 *
	 * @param \Thombo\Sishandball2\Domain\Model\Matchday $matchday
	 * @return void
	 */
	public function addMatchday(\Thombo\Sishandball2\Domain\Model\Matchday $matchday) {
		if(count($matchday->getMatches()) != 0) {
			$this->matchdays->attach($matchday);
			$this->aMatchDays[] = date('yW',$matchday->getMatches()->current()->getMatchdate()->format('U'));
		}
	}

	/**
	 * Removes a Matchday
	 *
	 * @param \Thombo\Sishandball2\Domain\Model\Matchday $matchdayToRemove The Matchday to be removed
	 * @return void
	 */
	public function removeMatchday(\Thombo\Sishandball2\Domain\Model\Matchday $matchdayToRemove) {
		$this->matchdays->detach($matchdayToRemove);
	}

	/**
	 * Returns the matchdays
	 *
	 * @return \TYPO3\CMS\Extbase\Persistence\ObjectStorage<\Thombo\Sishandball2\Domain\Model\Matchday> $matchdays
	 */
	public function getMatchdays() {
		return $this->matchdays;
	}

	/**
	 * Sets the matchdays
	 *
	 * @param \TYPO3\CMS\Extbase\Persistence\ObjectStorage<\Thombo\Sishandball2\Domain\Model\Matchday> $matchdays
	 * @return void
	 */
	public function setMatchdays(\TYPO3\CMS\Extbase\Persistence\ObjectStorage $matchdays) {
		$this->matchdays = $matchdays;
	}

	/**
	 * Sets the matchdays and matches by a queryresult
	 *
	 * @param \TYPO3\CMS\Extbase\Persistence\Generic\QueryResult $matches
	 * @return void
	 */
	public function parseQueryResult(\TYPO3\CMS\Extbase\Persistence\Generic\QueryResult $matches) {
		if(count($matches) != 0) {
			$bActSet = FALSE;

			$objMatchDay = new \Thombo\Sishandball2\Domain\Model\Matchday();

			$iCompare = date('yW',$matches[0]->getMatchdate()->format('U'));
			if($this->settings['nextmatchdaycheckbox'] && !$bActSet && $iCompare >= date('yW')) {
				$bActSet = TRUE;
				$objMatchDay->setActmatchday(TRUE);
			}

			foreach($matches as $match) {
				if($this->checkClub($match)) {
					if(date('yW',$match->getMatchdate()->format('U')) != $iCompare) {
						$this->addMatchday($objMatchDay);
						$objMatchDay = new \Thombo\Sishandball2\Domain\Model\Matchday();
						$iCompare = date('yW',$match->getMatchdate()->format('U'));
						if($this->settings['nextmatchdaycheckbox'] && !$bActSet && $iCompare >= date('yW')) {
							$bActSet = TRUE;
							$objMatchDay->setActmatchday(TRUE);
						}
					}

					$objMatchDay->addMatch($match);
				}
			}

			if(count($objMatchDay->getMatches()) != 0) {
				$this->addMatchday($objMatchDay);
			}
		}
	}

	/**
	* Deletes the unneeded matchdays
	 * @param int $iFrom
	 * @param int $iItemcount
	 * @return void
	 */
	public function setOffset($iFrom, $iItemcount) {
		$iCounter = 0;
		$aToDelete = array();

		foreach($this->matchdays as $objMatchDay) {
			if($iCounter < $iFrom || $iCounter >= ($iFrom + $iItemcount)) {
				$aToDelete[] = $objMatchDay;
			}

			$iCounter++;
		}

		foreach($aToDelete as $objMatchDay) {
			$this->removeMatchday($objMatchDay);
		}
	}

	/**
	* accept an settingarray
	* @param array $settings
	* @return void
	*/
	public function setSettings($settings) {
		$this->settings = $settings;
	}

	private function checkClub($match) {
		if(!empty($this->settings['clubSelection'])) {
			if($match->getHome()->getClub() !== $this->settings['clubSelection'] &&
			   $match->getGuest()->getClub() !== $this->settings['clubSelection']) {
				return FALSE;
			}
		}

		return TRUE;
	}

}
?>