<?php
namespace Thombo\Sishandball2\Domain\Repository;

/***************************************************************
 *  Copyright notice
 *
 *  (c) 2013 Thomas Bodenbender <info@thombo.com>, thombo Softwareentwicklung und IT-Beratungs GmbH
 *
 *  All rights reserved
 *
 *  This script is part of the TYPO3 project. The TYPO3 project is
 *  free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  The GNU General Public License can be found at
 *  http://www.gnu.org/copyleft/gpl.html.
 *
 *  This script is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  This copyright notice MUST APPEAR in all copies of the script!
 ***************************************************************/

/**
 *
 *
 * @license http://www.gnu.org/licenses/gpl.html GNU General Public License, version 3 or later
 *
 */
class MatchRepository extends \TYPO3\CMS\Extbase\Persistence\Repository {

	/**
	 * SpecialSettings
	 * @var array
	 **/
	private $aConf;

	public function setConfiguration($sSubpart, $aConf) {
		$this->aConf = $aConf[$sSubpart];
		$this->aConf['view'] = $sSubpart;

		$objQuerySettings = $this->objectManager->get('TYPO3\\CMS\\Extbase\\Persistence\\Generic\\Typo3QuerySettings');

		$objQuerySettings->setRespectStoragePage(TRUE);
		$objQuerySettings->setIgnoreEnableFields(TRUE);
		$objQuerySettings->setStoragePageIds(array($aConf['pages']));

		$this->setDefaultQuerySettings($objQuerySettings);
	}

	public function findRequested() {
		$aConstraints = array();
		$bReverseOrdering = FALSE;

		$objQuery = $this->createQuery();

		if($this->aConf['view'] == 'teammatches') {
			switch($this->aConf['displaySelection']) {
				/**
				* Spiele der gesamten Saison
				*/
				case '1':
					if(!$this->aConf['onlyhomematchescheckbox']) {
						$objQuery->matching(
							$objQuery->logicalOr(
								$objQuery->equals('home',$this->aConf['teamSelection']),
								$objQuery->equals('guest',$this->aConf['teamSelection'])
							)
						);
					} else {
						$objQuery->matching(
							$objQuery->equals('home',$this->aConf['teamSelection'])
						);
					}

				break;

				/**
				* der nchsten Spiele
				*/
				case '2':
					$aConstraints = array();
					$aConstraints[] = $objQuery->greaterThan('matchdate',date_create());

					if(!$this->aConf['onlyhomematchescheckbox']) {
						$aConstraints[] = $objQuery->logicalOr(
							$objQuery->equals('home',$this->aConf['teamSelection']),
							$objQuery->equals('guest',$this->aConf['teamSelection'])
						);
					} else {
						$aConstraints[] = $objQuery->equals('home',$this->aConf['teamSelection']);
					}

					$objQuery->matching($objQuery->logicalAnd($aConstraints));

					if(!empty($this->aConf['matchcount'])) {
						$objQuery->setLimit(intval($this->aConf['matchcount']));
					}
					break;

				/**
				 * des aktuellen Spieltags
				 */
				case '3':
					$iTestTimestamp = time();
					$iTestdayNo = date('w',$iTestTimestamp);
					if($iTestdayNo == 0) {
						$iTestdayNo = 7;
					}

					$iFromTime = time();
					if($iTestdayNo >= $this->aConf['nextdayactual']) {
						$iFromTime = $this->getMonday($iTestTimestamp);
					} else {
						$iFromTime = $this->getMonday($iTestTimestamp - (60*60*24*7));
					}

					$aConstraints = array();
					$aConstraints[] = $objQuery->greaterThan('matchdate',date_create(date('Y-m-d',$iFromTime)));

					$aConstraints[] = $objQuery->logicalOr(
						$objQuery->equals('home',$this->aConf['teamSelection']),
						$objQuery->equals('guest',$this->aConf['teamSelection'])
					);

					$objQuery->matching($objQuery->logicalAnd($aConstraints));

					$objQuery->setLimit(1);
					break;

				/**
				 *  des letzten Spieles
			 	 */
				case '4':
					$aConstraints = array();

					$aConstraints[] = $objQuery->lessThan('matchdate',date_create());

					if(!$this->aConf['onlyhomematchescheckbox']) {
						$aConstraints[] = $objQuery->logicalOr(
							$objQuery->equals('home',$this->aConf['teamSelection']),
							$objQuery->equals('guest',$this->aConf['teamSelection'])
						);
					} else {
						$aConstraints[] = $objQuery->equals('home',$this->aConf['teamSelection']);
					}

					$objQuery->matching($objQuery->logicalAnd($aConstraints));

					$objQuery->setLimit(intval($this->aConf['matchcount']));

					$objQuery->setOrderings(array('matchdate' => 'DESC'));

					$bReverseOrdering = TRUE;
					break;
			}
		}

		if($this->aConf['view'] == 'leaguematches') {
			$aTimeConstraints = array();
			$aConstraints[] = $objQuery->equals('league', $this->aConf['leagueSelection']);

			if($this->aConf['displaySelection'] == 2 || $this->aConf['displaySelection'] == 3) {
				if($this->aConf['displaySelection'] == 2) {
					$iTestTimestamp = time();
					$iTestdayNo = date('w',$iTestTimestamp);
					if($iTestdayNo == 0) {
						$iTestdayNo = 7;
					}

					$iFromTime = time();
					if($iTestdayNo >= $this->aConf['nextdayactual']) {
						$iFromTime = $this->getMonday($iTestTimestamp);
					} else {
						$iFromTime = $this->getMonday($iTestTimestamp - (60*60*24*7));
					}

					if(!empty($this->aConf['relativeweekend'])) {
						$iFromTime = strtotime('+'.$this->aConf['relativeweekend'].' week', $iFromTime);
					}
				} else {
					$iFromTime = $this->getMonday($this->aConf['absoluteweekend']);
				}

				$iUntilTime = strtotime('+1 week', $iFromTime) - 1;

				$aTimeConstraints[] = $objQuery->greaterThan('matchdate',date_create(date('Y-m-d H:i:s',$iFromTime)));
				$aTimeConstraints[] = $objQuery->lessThanOrEqual('matchdate',date_create(date('Y-m-d H:i:s',$iUntilTime)));

				if($this->aConf['jumptonextrealmatch']) {
					$objQuery->matching($objQuery->logicalAnd(array_merge($aConstraints,$aTimeConstraints)));

					$matches = $objQuery->execute();

					if(count($matches) == 0) {
						$objInternalQuery = $this->createQuery();

						$aTimeConstraints = array();
						$aConstraints[] = $objInternalQuery->greaterThan('matchdate',date_create(date('Y-m-d H:i:s',$iUntilTime)));
						$objInternalQuery->matching($objInternalQuery->logicalAnd(array_merge($aConstraints,$aTimeConstraints)));
						$objInternalQuery->setLimit(1);

						$matches = $objInternalQuery->execute();

						if(count($matches) != 0) {
							$iNewFromTime = $this->getMonday($matches[0]->getMatchdate()->format('U'));
							$iNewUntilTime = strtotime('+1 week', $iNewFromTime) - 1;

							$aTimeConstraints = array();
							$aTimeConstraints[] = $objQuery->greaterThan('matchdate',date_create(date('Y-m-d H:i:s',$iNewFromTime)));
							$aTimeConstraints[] = $objQuery->lessThanOrEqual('matchdate',date_create(date('Y-m-d H:i:s',$iNewUntilTime)));
						} else {
							return $matches;
						}
					}
				}
			}

			if(!empty($aTimeConstraints)) {
				$aConstraints[] = $objQuery->logicalAnd($aTimeConstraints);
			}
		}

		if($this->aConf['view'] == 'clubmatches') {
			if(empty($this->aConf['specialselection'])) {
				$aConstraints[] = $objQuery->logicalOr(
					$objQuery->in('home', $this->aConf['teams']),
					$objQuery->in('guest', $this->aConf['teams'])
				);
			} elseif($this->aConf['specialselection'] == 1) {
				$aConstraints[] = $objQuery->equals('home.club', $this->aConf['clubSelection']);
			} elseif($this->aConf['specialselection'] == 2) {
				$aConstraints[] = $objQuery->equals('guest.club', $this->aConf['clubSelection']);
			}

			if($this->aConf['displayselection'] == 2 || $this->aConf['displayselection'] == 3) {
				if($this->aConf['displayselection'] == 2) {
					$iTestTimestamp = time();
					$iTestdayNo = date('w',$iTestTimestamp);
					if($iTestdayNo == 0) {
						$iTestdayNo = 7;
					}

					$iFromTime = time();
					if($iTestdayNo >= $this->aConf['nextdayactual']) {
						$iFromTime = $this->getMonday($iTestTimestamp);
					} else {
						$iFromTime = $this->getMonday($iTestTimestamp - (60*60*24*7));
					}

					if(!empty($this->aConf['relativeweekend'])) {
						$iFromTime = strtotime('+'.$this->aConf['relativeweekend'].' week', $iFromTime);
					}
				} else {
					$iFromTime = $this->getMonday($this->aConf['absoluteweekend']);
				}

				$iUntilTime = strtotime('+1 week', $iFromTime);

				$aTimeConstraints[] = $objQuery->logicalAnd(
										$objQuery->greaterThanOrEqual('matchdate',date_create(date('Y-m-d H:i:s',$iFromTime))),
										$objQuery->lessThan('matchdate',date_create(date('Y-m-d H:i:s',$iUntilTime)))
									  );

				if($this->aConf['jumptonextrealmatch']) {
					$objConstraints = $objQuery->logicalAnd(array_merge($aConstraints,$aTimeConstraints));

					$objQuery->matching($objConstraints);

					$matches = $objQuery->execute();

					if(count($matches) == 0) {
						$objInternalQuery = $this->createQuery();

						$objTimeConstraints = $objInternalQuery->greaterThan('matchdate',date_create(date('Y-m-d H:i:s',$iUntilTime)));
						$objConstraints = $objInternalQuery->logicalAnd($aConstraints);

						$objInternalQuery->matching($objInternalQuery->logicalAnd($objConstraints,$objTimeConstraints));
						$objInternalQuery->setLimit(1);

						$matches = $objInternalQuery->execute();

						if(count($matches) != 0) {
							$iNewFromTime = $this->getMonday($matches[0]->getMatchdate()->format('U'));
							$iNewUntilTime = strtotime('+1 week', $iNewFromTime);

							$aTimeConstraints = array();
							$aTimeConstraints[] = $objQuery->greaterThanOrEqual('matchdate',date_create(date('Y-m-d H:i:s',$iNewFromTime)));
							$aTimeConstraints[] = $objQuery->lessThan('matchdate',date_create(date('Y-m-d H:i:s',$iNewUntilTime)));
						} else {
							return $matches;
						}
					}
				}

				$aConstraints = array_merge($aConstraints,$aTimeConstraints);
			}
		}

		if($this->aConf['view'] == 'table') {
			$aConstraints[] = $objQuery->equals('league', $this->aConf['leagueSelection']);

			if(!(bool)$this->aConf['displaywithoutsoring']) {
				$aConstraints[] = $objQuery->logicalNot($objQuery->in('uid', $this->aConf['teams']));
			}
		}

		if($this->aConf['view'] == 'crosstable') {
			$aConstraints[] = $objQuery->equals('league', $this->aConf['leagueSelection']);
		}

		if(!$bReverseOrdering) {
			$objQuery->setOrderings(array('matchdate' => 'ASC'));
		}

		if(!empty($aConstraints)) {
			$objQuery->matching($objQuery->logicalAnd($aConstraints));
		}

		return $objQuery->execute();
	}

	private function getMonday($iTimeStamp) {
		$iMonday = '';

		if (strftime("%w",$iTimeStamp) != 0) {
			$iMonday = mktime(0,0,0,strftime("%m",$iTimeStamp),strftime("%d",$iTimeStamp)-strftime("%w",$iTimeStamp)+1,strftime("%Y",$iTimeStamp));
		} else {
			$iMonday = mktime(0,0,0,strftime("%m",$iTimeStamp),strftime("%d",$iTimeStamp)-6,strftime("%Y",$iTimeStamp));
		}

		return $iMonday;
	}

	public function findByLeague($iLeagueUid, $iStorageUid) {
		$objQuerySettings = $this->objectManager->get('TYPO3\\CMS\\Extbase\\Persistence\\Generic\\Typo3QuerySettings');

		$objQuerySettings->setRespectStoragePage(TRUE);
		$objQuerySettings->setStoragePageIds(array($iStorageUid));

		$this->setDefaultQuerySettings($objQuerySettings);

		$objQuery = $this->createQuery();
		$objQuery->matching($objQuery->equals('league',$iLeagueUid));
		$objQuery->setOrderings(array('matchdate' => 'ASC'));

		return $objQuery->execute();
	}

	public function findByLeagueAndHomeTeam($iLeagueUid, $iTeamUid, $iStorageUid) {
		$objQuerySettings = $this->objectManager->get('TYPO3\\CMS\\Extbase\\Persistence\\Generic\\Typo3QuerySettings');

		$objQuerySettings->setRespectStoragePage(TRUE);
		$objQuerySettings->setStoragePageIds(array($iStorageUid));

		$this->setDefaultQuerySettings($objQuerySettings);

		$objQuery = $this->createQuery();

		$constraint1 = $objQuery->equals('home', $iTeamUid);
		$constraint2 = $objQuery->equals('league',$iLeagueUid);

		$objQuery->matching($objQuery->logicalAnd($constraint1, $constraint2));
		$objQuery->setOrderings(array('matchdate' => 'ASC'));

		return $objQuery->execute();
	}

	public function findByLeagueAndGuestTeam($iLeagueUid, $iTeamUid, $iStorageUid) {
		$objQuerySettings = $this->objectManager->get('TYPO3\\CMS\\Extbase\\Persistence\\Generic\\Typo3QuerySettings');

		$objQuerySettings->setRespectStoragePage(TRUE);
		$objQuerySettings->setStoragePageIds(array($iStorageUid));

		$this->setDefaultQuerySettings($objQuerySettings);

		$objQuery = $this->createQuery();

		$constraint1 = $objQuery->equals('guest', $iTeamUid);
		$constraint2 = $objQuery->equals('league',$iLeagueUid);

		$objQuery->matching($objQuery->logicalAnd($constraint1, $constraint2));
		$objQuery->setOrderings(array('matchdate' => 'ASC'));

		return $objQuery->execute();
	}

	/**
	 * Find matches by teamlist
	 *
	 * @param \TYPO3\CMS\Extbase\Persistence\QueryResultInterface $teams
	 * @param \integer $iStorageUid
	 * @return \TYPO3\CMS\Extbase\Persistence\QueryResultInterface
	 */
	public function findByTeams(\TYPO3\CMS\Extbase\Persistence\QueryResultInterface $teams, $iStorageUid) {
		$objQuerySettings = $this->objectManager->get('TYPO3\\CMS\\Extbase\\Persistence\\Generic\\Typo3QuerySettings');

		$objQuerySettings->setRespectStoragePage(TRUE);
		$objQuerySettings->setStoragePageIds(array($iStorageUid));

		$this->setDefaultQuerySettings($objQuerySettings);

		$objQuery = $this->createQuery();

		$constraint = $objQuery->logicalOr($objQuery->in('home', $teams), $objQuery->in('guest', $teams));

		$objQuery->matching($constraint);
		$objQuery->setOrderings(array('matchdate' => 'ASC'));

		return $objQuery->execute();
	}
}
?>