<?php
namespace Thombo\Sishandball2\Scheduler;

/***************************************************************
 *  Copyright notice
 *
 *  (c) 2013 Thomas Bodenbender <info@thombo.com>
 *  thombo Softwareentwicklung und IT-Beratungs GmbH
 *
 *  All rights reserved
 *
 *  This script is part of the TYPO3 project. The TYPO3 project is
 *  free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  The GNU General Public License can be found at
 *  http://www.gnu.org/copyleft/gpl.html.
 *
 *  This script is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  This copyright notice MUST APPEAR in all copies of the script!
 ***************************************************************/

class UpdateTaskAdditionals implements \TYPO3\CMS\Scheduler\AdditionalFieldProviderInterface {

	public function getAdditionalFields(array &$taskInfo, $task, \TYPO3\CMS\Scheduler\Controller\SchedulerModuleController $parentObject) {
		$rLeagues = $GLOBALS['TYPO3_DB']->exec_SELECTquery('tx_sishandball2_domain_model_league.uid as league_uid,
                                                            tx_sishandball2_domain_model_league.name as league_name,
                                                            pages.title as page_title',
		                                                   'tx_sishandball2_domain_model_league,
                                                            pages',
		                                                   'tx_sishandball2_domain_model_league.pid = pages.uid',
		                                                   '',
		                                                   'pages.sorting,
                                                            tx_sishandball2_domain_model_league.sorting');

		$htmlFormCode = '<style type="text/css">
							.pagetitle { color: #555555; margin-bottom: 5px; font-style: italic; list-style-type: none; font-weight: bold; }
							.league { color: black; margin-bottom: 0px; font-style: normal; list-style-type: none; font-weight: normal; }
							.leagueselection { list-style-type: none; }
						 </style>
						 <ul class="leagueselection">';

		$sPageTitle = '';
		while($aLeagues = $GLOBALS['TYPO3_DB']->sql_fetch_assoc($rLeagues)) {
			if($sPageTitle != $aLeagues['page_title']) {
				$sPageTitle = $aLeagues['page_title'];
				if($htmlFormCode != '<ul>') {
					$htmlFormCode .= '</ul></li>';
				}
				$htmlFormCode .= '<li class="pagetitle">'.$sPageTitle.'<ul>';
			}

			$sChecked = '';
			if(!empty($task->leagueuids) && \TYPO3\CMS\Core\Utility\GeneralUtility::inList($task->leagueuids, intval($aLeagues['league_uid']))) {
				$sChecked = ' checked="checked"';
			}

			$htmlFormCode .= '<li class="league"><input type="checkbox" name="tx_scheduler[leagueids][]" id="league'.intval($aLeagues['league_uid']).'" value="'.intval($aLeagues['league_uid']).'" '.$sChecked.'/> <label for="league'.intval($aLeagues['league_uid']).'">'.$aLeagues['league_name'].'</label></li>';
		}

		$htmlFormCode .= '</ul></li></ul>';

		$sFieldID = 'leagueids';
		$additionalFields = array();
		$additionalFields[$sFieldID] = array(
			'code'     => $htmlFormCode,
			'label'    => 'LLL:EXT:sishandball2/Resources/Private/Language/locallang.xml:tasklabel.leagueids',
			'cshKey'   => '_MOD_tools_txschedulerM1',
			'cshLabel' => $sFieldID
		);

		return $additionalFields;
	}

	public function validateAdditionalFields(array &$submittedData, \TYPO3\CMS\Scheduler\Controller\SchedulerModuleController $parentObject) {
		$result = TRUE;
		if(empty($submittedData['leagueids'])) {
			$message = \TYPO3\CMS\Extbase\Utility\LocalizationUtility::translate('LLL:EXT:sishandball2/Resources/Private/Language/locallang.xlf:msg.noleagueids');
			$parentObject->addMessage($message, \TYPO3\CMS\Core\Messaging\FlashMessage::ERROR);
			$result = FALSE;
		} else {
			$lLeagueIds = '';
			if(!empty($submittedData['leagueids']) && is_array($submittedData['leagueids'])) {
				foreach($submittedData['leagueids'] as $iLeagueId) {
					if(!empty($lLeagueIds)) {
						$lLeagueIds .= ',';
					}

					$lLeagueIds .= intval($iLeagueId);
				}
			}

			$iPageCount = $GLOBALS['TYPO3_DB']->exec_SELECTcountRows('DISTINCT pages.uid',
				                                                     'pages,
                                                                      tx_sishandball2_domain_model_league',
			                                                         'tx_sishandball2_domain_model_league.pid = pages.uid AND
                                                                      tx_sishandball2_domain_model_league.uid IN ('.$lLeagueIds.')');

			if($iPageCount > 1) {
				$message = \TYPO3\CMS\Extbase\Utility\LocalizationUtility::translate('LLL:EXT:sishandball2/Resources/Private/Language/locallang.xlf:msg.morethanonepage');
				$parentObject->addMessage($message, \TYPO3\CMS\Core\Messaging\FlashMessage::ERROR);
				$result = FALSE;
			}
		}

		return $result;
	}

	public function saveAdditionalFields(array $submittedData, \TYPO3\CMS\Scheduler\Task\AbstractTask $task) {
		$lLeagueIds = '';
		if(!empty($submittedData['leagueids']) && is_array($submittedData['leagueids'])) {
			foreach($submittedData['leagueids'] as $iLeagueId) {
				if(!empty($lLeagueIds)) {
					$lLeagueIds .= ',';
				}

				$lLeagueIds .= intval($iLeagueId);
			}
		}

		$aPageUid = $GLOBALS['TYPO3_DB']->exec_SELECTgetRows('DISTINCT pages.uid',
		                                                     'pages,
                                                              tx_sishandball2_domain_model_league',
		                                                     'tx_sishandball2_domain_model_league.pid = pages.uid AND
                                                              tx_sishandball2_domain_model_league.uid IN ('.$lLeagueIds.')');

		if(!empty($aPageUid[0]['uid'])) {
			$task->pid = $aPageUid[0]['uid'];
		}

		$task->leagueuids = $lLeagueIds;
	}

}